@@ -59,7 +59,6 @@ diat_cemfgs_rb <- function(resultLoad){
   #gets the column named "new_species", everything before that is a sample
   lastcol <- which(colnames(taxaIn)=="new_species")
 
-
   #######--------CEMFGS_RG INDEX START --------#############
   print("Calculating CEMFGS_RG")
   #creates results dataframe
@@ -76,131 +75,84 @@ diat_cemfgs_rb <- function(resultLoad){
   PS1 <- PS2 <- PS3 <- PS4 <- PS5 <- NULL
   CEMFGS_class_Indet <- CEMFGS_Taxa_used <- CEMFGS_RB_Indet <- NULL
 
+
+  #OBSOLETE CODE FROM V0.1.4
+  # data.table::setDT(taxaIn)
+  # cemfgs_rb.results <- suppressWarnings(data.table(
+  #   HS1 <- unlist(taxaIn[which(cemfgs_rb == "HS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                            1)]),
+  #   HS2 <- unlist(taxaIn[which(cemfgs_rb == "HS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   HS3 <- unlist(taxaIn[which(cemfgs_rb == "HS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   HS4 <- unlist(taxaIn[which(cemfgs_rb == "HS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   HS5 <- unlist(taxaIn[which(cemfgs_rb == "HS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   LS1 <- unlist(taxaIn[which(cemfgs_rb == "LS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   LS2 <- unlist(taxaIn[which(cemfgs_rb == "LS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   LS3 <- unlist(taxaIn[which(cemfgs_rb == "LS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   LS4 <- unlist(taxaIn[which(cemfgs_rb == "LS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   LS5 <- unlist(taxaIn[which(cemfgs_rb == "LS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   MS1 <- unlist(taxaIn[which(cemfgs_rb == "MS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   MS2 <- unlist(taxaIn[which(cemfgs_rb == "MS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   MS3 <- unlist(taxaIn[which(cemfgs_rb == "MS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   MS4 <- unlist(taxaIn[which(cemfgs_rb == "MS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   MS5 <- unlist(taxaIn[which(cemfgs_rb == "MS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   PS1 <- unlist(taxaIn[which(cemfgs_rb == "PS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   PS2 <- unlist(taxaIn[which(cemfgs_rb == "PS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   PS3 <- unlist(taxaIn[which(cemfgs_rb == "PS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   PS4 <- unlist(taxaIn[which(cemfgs_rb == "PS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)]),
+  #   PS5 <- unlist(taxaIn[which(cemfgs_rb == "PS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol -
+  #                                                                                                 1)])
+  # ))
+  #
+  #
+
+  ### NEW CODE FROM V0.1.5 ONWARDS
   data.table::setDT(taxaIn)
 
-  cemfgs_rb.results <- suppressWarnings(data.table::data.table(
-    HS1 = if (nrow(taxaIn[which(cemfgs_rb == "HS1")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "HS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
+  # Define the groups
+  groups <- c("HS1", "HS2", "HS3", "HS4", "HS5",
+              "LS1", "LS2", "LS3", "LS4", "LS5",
+              "MS1", "MS2", "MS3", "MS4", "MS5",
+              "PS1", "PS2", "PS3", "PS4", "PS5")
 
-    HS2 = if (nrow(taxaIn[which(cemfgs_rb == "HS2")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "HS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
+  # Initialize an empty data.table
+  cemfgs_rb.results <- data.table(matrix(0, nrow = (lastcol - 1), ncol = length(groups)))
 
-    HS3 = if (nrow(taxaIn[which(cemfgs_rb == "HS3")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "HS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
+  # Add column names
+  setnames(cemfgs_rb.results, groups)
 
-    HS4 = if (nrow(taxaIn[which(cemfgs_rb == "HS4")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "HS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
+  # Calculate sums and add to results
+  for (group in groups) {
+    group_data <- taxaIn[cemfgs_rb == group,
+                         lapply(.SD, sum, na.rm = TRUE),
+                         .SDcols = 1:(lastcol - 1)]
 
-    HS5 = if (nrow(taxaIn[which(cemfgs_rb == "HS5")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "HS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    LS1 = if (nrow(taxaIn[which(cemfgs_rb == "LS1")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "LS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    LS2 = if (nrow(taxaIn[which(cemfgs_rb == "LS2")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "LS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    LS3 = if (nrow(taxaIn[which(cemfgs_rb == "LS3")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "LS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    LS4 = if (nrow(taxaIn[which(cemfgs_rb == "LS4")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "LS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    LS5 = if (nrow(taxaIn[which(cemfgs_rb == "LS5")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "LS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    MS1 = if (nrow(taxaIn[which(cemfgs_rb == "MS1")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "MS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    MS2 = if (nrow(taxaIn[which(cemfgs_rb == "MS2")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "MS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    MS3 = if (nrow(taxaIn[which(cemfgs_rb == "MS3")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "MS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    MS4 = if (nrow(taxaIn[which(cemfgs_rb == "MS4")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "MS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    MS5 = if (nrow(taxaIn[which(cemfgs_rb == "MS5")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "MS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    PS1 = if (nrow(taxaIn[which(cemfgs_rb == "PS1")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "PS1"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    PS2 = if (nrow(taxaIn[which(cemfgs_rb == "PS2")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "PS2"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    PS3 = if (nrow(taxaIn[which(cemfgs_rb == "PS3")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "PS3"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    PS4 = if (nrow(taxaIn[which(cemfgs_rb == "PS4")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "PS4"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
-    },
-
-    PS5 = if (nrow(taxaIn[which(cemfgs_rb == "PS5")]) == 0) {
-      rep(0, lastcol - 1)
-    } else {
-      unlist(taxaIn[which(cemfgs_rb == "PS5"), lapply(.SD, sum, na.rm = TRUE), .SDcols = 1:(lastcol - 1)])
+    if (nrow(group_data) > 0) {
+      cemfgs_rb.results[[group]] <- unlist(group_data)
     }
-  ))
+  }
 
-  #replace NAs for 0
+
+  #### END NEW VERSION
+
+    #replace NAs for 0
   cemfgs_rb.results[is.na(cemfgs_rb.results)] = 0
   cemfgs_rb.results[, `CEMFGS_RB_Indet` := round(100 - ( HS1 + HS2 + HS3 + HS4 + HS5 + LS1 + LS2 + LS3 + LS4 + LS5 + MS1 + MS2 + MS3 + MS4 + MS5 + PS1 + PS2 + PS3 + PS4 + PS5), 1)]
 
